| Title: | Data Sets for "Applied Survival Analysis Using R"" |
|---|---|
| Description: | Data sets are referred to in the text "Applied Survival Analysis Using R" by Dirk F. Moore, Springer, 2016, ISBN: 978-3-319-31243-9, <DOI:10.1007/978-3-319-31245-3>. |
| Authors: | Dirk F. Moore |
| Maintainer: | Dirk F. Moore <[email protected]> |
| License: | CC0 |
| Version: | 0.50 |
| Built: | 2026-05-14 06:26:23 UTC |
| Source: | https://github.com/cran/asaur |
This is a random subset of data from the Struewing et al. (1997) study of Ashkenazi jews and breast cancer. The subset consists of pairs of first-degree female relatives who are also first degree relatives of a proband.
data("ashkenazi")data("ashkenazi")
A data frame with 3920 observations on the following 4 variables.
famIDfamily ID indicator
brcancer1 if subject had breast cancer, 0 if not
ageAge at onset of breast cancer, or current age if no breast cancer
mutant1 if first degree relative proband was a BRCA mutation carrier, 0 if not
Moore DF, Chatterjee N, Pee D, and Gail MH (2001) Pseudo-likelihood estimates of the cumulative risk of an autosomal dominant disease from a kin-cohort study. Genetic Epidemiology 20, 210-227.)
Struewing JP, Hartge P, Wacholder S, Baker SM, Berlin M, McAdams M, Timmerman MM, Brody LC, and Tucker MA (1997) The risk of cancer associated with specific mutations of BRCA1 and BRCA2 among ashkenazi jews. New England Journal of Medicine 336, 1401-1408.)
data(ashkenazi)data(ashkenazi)
The ChanningHouse data frame has 457 rows and 5 columns. This is 5 fewer
than the parent channing data frame in the boot package. These 5 were
removed because the exit time was not smaller than the entry time.
Channing House is a retirement centre in Palo Alto, California. These data were collected between the opening of the house in 1964 until July 1, 1975. In that time 97 men and 365 women passed through the centre. For each of these, their age on entry and also on leaving or death was recorded. A large number of the observations were censored mainly due to the resident being alive on July 1, 1975 when the data was collected. Over the time of the study 130 women and 46 men died at Channing House. Differences between the survival of the sexes, taking age into account, was one of the primary concerns of this study.
data("ChanningHouse")data("ChanningHouse")
A data frame with 457 observations on the following 5 variables.
sexa factor for the sex of each resident with levels Female Male
entryThe residents age (in months) on entry to the center)
exitThe age (in months) of the resident on death, leaving the center or July 1, 1975, whichever event occurred first.)
timeThe length of time (in months) that the resident spent at Channing House. (time=exit-entry)))
censThe indicator of reight censoring. 1 indicates that the resident died at Channing House, 0 indicates that they left the house prior to July 1, 1975 or that they were still alive and living in the center at that date.
The current data were derived from the "channing" data frame in the "boot" package. The original source for the data was
Hyde, J. (1980) Testing survival with incomplete observations. Biostatistics Casebook. R.G. Miller, B. Efron, B.W. Brown and L.E. Moses (editors), 31-46. John Wiley.
Davison, A.C. and Hinkley, D.V. (1997) Bootstrap Methods and Their Application. Cambridge University Press.
Canty, A. and Ripley, B. (2015) boot package.
data(ChanningHouse)data(ChanningHouse)
Data from a Phase II clinical trial of Xeloda and exaliplatin given before surgery to advanced gastric cancer patients with para-aortic lymph node metastasis.
data("gastricXelox")data("gastricXelox")
A data frame with 48 observations on the following 2 variables.
timeWeekssurvival time in weeks
delta1 for death, 0 for censored
The data were extracted from the Kaplan-Meier survival plot.
Wang Y, Yu Y-Y, Li W, Feng Y, Hou J, Ji Y, Sun Y-H, Shen K-T, Shen Z-B, Qin X-Y, and Liu T-S. (2014) A phase II trial of xeloda and oxaliplatin (XELOX) neo-adjuvant chemotherapy followed by surgery for advanced gastric cancer patients with para-aortic lymph node metastasis. Cancer Chemotherapy and Pharmacology 73(6), 1155-1161.))
data(gastricXelox)data(gastricXelox)
Overall and recurrence-free survival of patients with hepatocellular carcinoma.
data("hepatoCellular")data("hepatoCellular")
A data frame with 227 observations on 48 clinical and biomarker variables
NumberPatient ID number
Agea numeric vector
Gendera numeric vector
HBsAga numeric vector
Cirrhosisa numeric vector
ALTa numeric vector
ASTa numeric vector
AFPa numeric vector
Tumorsizea numeric vector
Tumordifferentiationa numeric vector
Vascularinvasiona numeric vector
Tumormultiplicitya numeric vector
Capsulationa numeric vector
TNMa numeric vector
BCLCa numeric vector
OSOverall survival
Death1 denotes death, 0 censored
RFSRecurrence-free survival
Recurrence1 denotes recurrence, 0 censored
CXCL17Ta numeric vector
CXCL17Pa numeric vector
CXCL17Na numeric vector
CD4Ta numeric vector
CD4Na numeric vector
CD8Ta numeric vector
CD8Na numeric vector
CD20Ta numeric vector
CD20Na numeric vector
CD57Ta numeric vector
CD57Na numeric vector
CD15Ta numeric vector
CD15Na numeric vector
CD68Ta numeric vector
CD68Na numeric vector
CD4NRa numeric vector
CD8NRa numeric vector
CD20NRa numeric vector
CD57NRa numeric vector
CD15NRa numeric vector
CD68NRa numeric vector
CD4TRa numeric vector
CD8TRa numeric vector
CD20TRa numeric vector
CD57TRa numeric vector
CD15TRa numeric vector
CD68TRa numeric vector
Ki67a numeric vector
CD34a numeric vector
Li L, Yan J, Xu J, Liu C-Q, Zhen Z-J, Chen H-W, Ji Y, Wu Z-P, Hu J-Y, Zheng L, Lau WY (2014) Cxcl17 expression predicts poor prognosis and correlates with adverse immune infiltration in hepatocellular carcinoma. Plos One 9 (10) e110064.
Li L, Yan J, Xu J, Liu C-Q, Zhen Z-J, Chen H-W, Ji Y, Wu Z-P, Hu J-Y, Zheng L, Lau WY (2014) Cxcl17 expression predicts poor prognosis and correlates with adverse immune infiltration in hepatocellular carcinoma. Dryad Digital Repository datadryad.org.
data(hepatoCellular)data(hepatoCellular)
Data from a Phase II clinical trial of patients with locally advanced or metastatic pancreatic cancer.
data("pancreatic")data("pancreatic")
A data frame with 41 observations on the following 4 variables.
stagea factor with levels LA (locally advanced) or M (metastatic)
onstudydate of enrollment into the clinical trial, in month/day/year format
progressiondate of progression, in month/day/year format
deathdate of death, in month/day/year format
Since all patients in this study have known death dates, there is no censoring.
Moss RA, Moore D, Mulcahy MF, Nahum K, Saraiya B, Eddy S, Kleber M, and Poplin EA (2012) A multi-institutional phase 2 study of imatinib mesylate and gemcitabine for first-line treatment of advanced pancreatic cancer. Gastrointestinal Cancer Research 5, 77 - 83.
data(pancreatic)data(pancreatic)
This is the same data as in 'pancreatic', with overall and progression-free survival calculated. Dates have been removed.
data("pancreatic2")data("pancreatic2")
A data frame with 41 observations on the following 4 variables.
pfsProgression-free survival: Time from entry until disease progression. If no progression was observed, before death, the time to death is used.
osOverall survival: Time from entry until death
statusThis censoring indicator is 1 for all patients, since all patients died.
stagea factor with levels LA (locally advanced) or M (metastatic)
Moss RA, Moore D, Mulcahy MF, Nahum K, Saraiya B, Eddy S, Kleber M, and Poplin EA (2012) A multi-institutional phase 2 study of imatinib mesylate and gemcitabine for first-line treatment of advanced pancreatic cancer. Gastrointestinal Cancer Research 5, 77 - 83.
data(pancreatic2)data(pancreatic2)
Randomized trial of triple therapy vs. patch for smoking cessation.
data("pharmacoSmoking")data("pharmacoSmoking")
A data frame with 125 observations on the following 14 variables.
idpatient ID number
ttrTime in days until relapse
relapseIndicator of relapse (return to smoking)
grpRandomly assigned treatment group with levels combination or patchOnly
ageAge in years at time of randomization
genderFemale or Male
raceblack, hispanic, white, or other
employmentft (full-time), pt (part-time), or other
yearsSmokingNumber of years the patient had been a smoker
levelSmokingheavy or light
ageGroup2Age group with levels 21-49 or 50+
ageGroup4Age group with levels 21-34, 35-49, 50-64, or 65+
priorAttemptsThe number of prior attempts to quit smoking
longestNoSmokeThe longest period of time, in days, that the patient has previously gone without smoking
This data is from a clinical trial described in Steinberg et al. (2009)
Steinberg, M.B. Greenhaus, S. Schmelzer, A.C. Bover, M.T., Foulds, J., Hoover, D.R., and Carson, J.L. (2009) Triple-combination pharmacotherapy for medically ill smokers: A randomized trial. Annals of Internal Medicine 150, 447-454.
data(pharmacoSmoking)data(pharmacoSmoking)
This data set contains survival times for two competing causes: time from prostate cancer diagnosis to death from prostate cancer, and time from prostate cancer diagnosis to death from other causes. The data set also contains information on several risk factors. The data in this data set are simulated from detailed competing risk survival curves and counts of numbers of patients per group presented in Lu-Yao et al. (2009). Thus, the simulated data presented here contain many of the characteristics of the original SEER-Medicare prostate cancer data used in Lu-Yao et al. (2009).
data("prostateSurvival")data("prostateSurvival")
A data frame with 14294 observations on the following 5 variables.
gradea factor with levels mode (moderately differentiated) and poor (poorly differentiated)
stagea factor with levels T1ab (Stage T1, clinically diagnoseed),
T1c (Stage T1, diagnosed via a PSA test), and
T2 (Stage T2)
ageGroupa factor with levels 66-69 70-74 75-79 80+
survTimetime from diagnosis to death or last date known alive
statusa censoring variable, 0, (censored),
1 (death from prostate cancer), and 2 (death from other causes)
Lu-Yao, GL, Albertsen PC, Moore DF, Shih W, Lin Y, DiPaola RS, Barry MJ, Zietman A, O'Leary M, Walker-Corkery E, Yao S-L (2009) Outcomes of localized prostate cancer following conservative management. Journal of the American Medical Association 302, 1202 - 1209.)
data(prostateSurvival)data(prostateSurvival)